@@ -1,10 +1,9 @@
 context("manual expensive tests")
 
 test_that("rscimark", {
-  skip_if_not_installed("rscimark")
   skip("manual test")
 
-  reg = makeRegistry(file.dir = NA, make.default = FALSE, package = "rscimark")
+  reg = makeTestRegistry(package = "rscimark")
   reg$cluster.functions = makeClusterFunctionsMulticore(4)
   batchMap(rscimark, minimum.time = rep(1, 5), reg = reg)
   submitJobs(reg = reg)
@@ -12,7 +11,7 @@ test_that("rscimark", {
   tab = getJobTable(reg = reg)
   expect_true(tab$started[5] >= min(tab$done[1:4]))
 
-  reg = makeRegistry(file.dir = NA, make.default = FALSE)
+  reg = makeTestRegistry()
   reg$cluster.functions = makeClusterFunctionsMulticore(4)
   batchMap(Sys.sleep, rep(3, 4), reg = reg)
   submitJobs(reg = reg)
